===========
pysugarscape
===========

A simple agent-based implementation of Epstein & Axtell's sugarscape model.

Installation
------

    pip install pysugarscape

Usage:
------

To run the programme just open a console and type either

    pysugarscape_console  

to run the simple command line version.

or

    pysugarscape_gui  

to run a GTK+ version (requires pyGTK).
